@@ -64,6 +64,8 @@
 
 #define FILE_BUFFER_SIZE 1024
 
+static gchar *anjuta_prefix = "anjuta";
+
 static void
 anjuta_util_from_file_to_file (GInputStream *istream,
 							   GOutputStream *ostream)
@@ -2219,6 +2221,12 @@ anjuta_util_str_middle_truncate (const gchar *string,
  *
  */
 
+void
+anjuta_util_set_anjuta_prefix (const gchar *prefix)
+{
+	anjuta_prefix = g_strdup (prefix);
+}
+
 static gchar*
 anjuta_util_construct_pathv (const gchar* str, va_list str_list)
 {
@@ -2253,7 +2261,6 @@ anjuta_util_get_user_cache_filev (const gchar* path, va_list list)
 {
 	gchar *uri_str, *base_path, *dir;
 	GFile *uri;
-	const gchar anjuta_prefix[] = "anjuta";
 	base_path = g_build_filename (g_get_user_cache_dir(), anjuta_prefix, path, NULL);
 
 	uri_str = anjuta_util_construct_pathv (base_path, list);
@@ -2280,7 +2287,6 @@ anjuta_util_get_user_config_filev (const gchar* path, va_list list)
 {
 	gchar *uri_str, *base_path, *dir;
 	GFile *uri;
-	const gchar anjuta_prefix[] = "anjuta";
 	base_path = g_build_filename (g_get_user_config_dir(), anjuta_prefix, path, NULL);
 
 	uri_str = anjuta_util_construct_pathv (base_path, list);
@@ -2307,7 +2313,6 @@ anjuta_util_get_user_data_filev (const gchar* path, va_list list)
 {
 	gchar *uri_str, *base_path, *dir;
 	GFile *uri;
-	const gchar anjuta_prefix[] = "anjuta";
 	base_path = g_build_filename (g_get_user_data_dir(), anjuta_prefix, path, NULL);
 
 	uri_str = anjuta_util_construct_pathv (base_path, list);
